/*
 *  Kylin security execute control and Box module（模块，包功能介绍）
 *
 *  This file contains the definitions needed for Kylin security exectl
 *  functions
 *
 *  Authors:  WKL <wangkanglong@kylinos.cn>
 *
 *  Copyright (C) 2017,Tianjin KYLIN Information Technology Co., Ltd.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the
 *  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#ifndef KYSEC_DEVCTL_H
#define KYSEC_DEVCTL_H

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <ctype.h>

#ifdef __cplusplus
extern "C" {
#endif

#define DEVNAME_MAX 20
#define CHAR_MID_LEN 128
#define CHAR_MAX_LEN 256
#define DEVCTL_KERNEL_STRUCT 1

//设备类型
enum kysec_dev_type {
	KYSEC_USB = 1,
	KYSEC_SERIAL,
	KYSEC_PARALLEL,
	KYSEC_TYPEC,
	KYSEC_CDROM,
	KYSEC_PRINTER,
	KYSEC_WIRELESS,
	KYSEC_ETHERNET,
	KYSEC_SCANNER,
	KYSEC_AUDIO,
	KYSEC_DEV_MAX
};

//usb设备的类型
enum kysec_usb_type {
	KYSEC_HARD_DRIVE = 1,
	KYSEC_USB_CDROM,
	KYSEC_USB_PRINTER,
	KYSEC_USB_CAMERA,
	KYSEC_USB_BLUETOOTH,
	KYSEC_USB_STORAGE,
	KYSEC_USB_MAX
};

struct kysec_devctl_kernel {
	int type;
	int usb_subtype;
	unsigned int pid;
	unsigned int vid;
	int perm;
	int special_type;
	char serial[CHAR_MID_LEN];
	int version;
};
struct kysec_devctl_info {
	int type;
	int usb_subtype;
	unsigned int pid;
	unsigned int vid;
	int perm;
	int oldperm;
	char serial[CHAR_MID_LEN];
	int special_type;
	char displayname[CHAR_MAX_LEN];
};
struct kysec_devctl_ssid {
	char blkssid[CHAR_MID_LEN];
};

struct kysec_devctl_sysf {
	int dtype;
	unsigned int devpid;
	unsigned int devvid;
	int devperm;
	char product[CHAR_MID_LEN];
	char manufacturer[CHAR_MID_LEN];
	char serial[CHAR_MID_LEN];
	char dev_name[DEVNAME_MAX];
	char displayname[CHAR_MAX_LEN];
};

struct device_record {
	int type;
	int perm;
	unsigned int pid;
	unsigned int vid;
	char serial[CHAR_MID_LEN];
	char access_t[CHAR_MID_LEN];
	char duration[20];
	char displayname[CHAR_MAX_LEN];
};

/**
 * @name: kysec_devctl_add_perm
 * @Descripttion: 添加设备/接口的权限
 * @msg:
 * @param {struct kysec_devctl_info} * kysec_devctl_info结构体
 * @return 0:成功，-1:出错
 */
int kysec_devctl_add_perm(struct kysec_devctl_info *recv);


/**
 * @name: kysec_devctl_remove_perm
 * @Descripttion: 删除设备/接口的权限
 * @msg:
 * @param {struct kysec_devctl_info} * kysec_devctl_info结构体
 * @return 0:成功，-1:出错
 */
int kysec_devctl_remove_perm(struct kysec_devctl_info *recv);

/**
 * @name: kysec_devctl_change_perm
 * @Descripttion: 修改设备/接口的权限
 * @msg:
 * @param {struct kysec_devctl_info} * kysec_devctl_info结构体
 * @return 0:成功，-1：出错
 */
int kysec_devctl_update_perm(struct kysec_devctl_info *recv);

/**
 * @name: kysec_devctl_wireless_ctl_add
 * @Descripttion: 添加无线网络热点名称到黑名单
 * @msg:
 * @param {const char} *  热点名称
 * @return 0:成功，-1：出错
 */
int kysec_devctl_wireless_ctl_add(const char * ssid);

/**
 * @name:  kysec_devctl_wireless_ctl_del
 * @Descripttion: 删除黑名单中的无线网络热点
 * @msg:
 * @param {const char} *    热点名称
 * @return {*}  0:成功，-1：出错
 */
int kysec_devctl_wireless_ctl_del(const char * ssid);

/**
 * @Descripttion: 批量添加设备/接口的权限
 * @data： 设备信息
 * @count: 添加个数
 * @return 0:成功，-1:出错
 */
int kysec_devctl_batch_add_perm(struct kysec_devctl_info *data, int count);

/**
 * @name: kysec_devctl_read_all_dev_data
 * @Descripttion: 获取所有设备的权限
 * @msg:
 * @param {int} *count  添加的设备个数
 * @return {*}
 */
struct kysec_devctl_info * kysec_devctl_read_all_dev_data(int *count);


/**
 * @name: kysec_devctl_read_all_ssid_data
 * @Descripttion: 获取所有的热点黑名单
 * @msg:
 * @param {int} *count  黑名单的个数
 * @return {*}
 */
struct kysec_devctl_ssid * kysec_devctl_read_all_ssid_data(int *count);

/**
 * @name:  kysec_devctl_read_not_special_data
 * @Descripttion: 获取非指定设备的权限
 * @msg: 
 * @param {int} *count
 * @return {*}
 */
struct kysec_devctl_info * kysec_devctl_read_not_special_data(int *count);

/**
 * @name: kysec_devctl_read_special_xmldata
 * @Descripttion: 获取special设备的设备名和权限
 * @msg: 
 * @param {int} *count special 设备的个数
 * @return {*}
 */
struct kysec_devctl_info *kysec_devctl_read_special_xmldata(int *count);


/**
 * @name: kysec_devctl_read_sys_devinfo
 * @Descripttion: 读取sys下的设备信息文件
 * @msg: 
 * @param {int} *count  个数
 * @return {*}
 */
struct kysec_devctl_sysf *kysec_devctl_read_sys_devinfo(int *count);

/**
 * @name: kysec_devctl_sync_config
 * @Descripttion: 核外设备同步权限
 * @msg:
 * @param {int} type  类型
 * @param {int} perm 权限
 * @return {*}
 */
int kysec_devctl_auto_sync_config(void *data);

/**
 * @name: device_record_get
 * @Descripttion: 获取60天以内的设备连接记录
 * @msg:
 * @param {int} *count 个数
 * @return {*}
 */
struct device_record *device_record_get(int *count);

/**
 * @name: kysec_devctl_xdg_insert_record
 * @Descripttion: 获取设备连接记录
 * @msg:
 * @param {struct device_record} *record 设备连接记录
 * @param { int } count  个数
 * @return {*} 0:成功，-1：出错
 */
int kysec_devctl_xdg_insert_record(struct device_record *record, int count);

/**
 * @name: kysec_devctl_switch_status
 * @Descripttion: 切换设备管控状态
 * @msg:
 * @param {int} status 状态，0关闭，1开启
 * @return {*} 0:成功，-1：出错
 */
int kysec_devctl_switch_status(int status);

#ifdef __cplusplus
}
#endif

#endif
